Model Code:

.. literalinclude:: /../../cis_interface/examples/formatted_io1/src/formatted_io1_modelA.py
   :language: python
   :linenos:

.. literalinclude:: /../../cis_interface/examples/formatted_io1/src/formatted_io1_modelB.py
   :language: python
   :linenos:


(`Example in other languages <examples/formatted_io1.html>`__)
